# 50MHz board input clock
#create_clock -period 20 [get_ports clk_clk]

#**************************************************************
# Time Information
#**************************************************************

set_time_format -unit ns -decimal_places 3


# 1000MHz: Period = 8ns		|	 100MHz: Period = 40ns	 |	 10MHz: Period = 400ns 
set RX_CLK_125M_PERIOD	8
set RX_CLK_25M_PERIOD	40
set RX_CLK_2_5M_PERIOD	400

# 1000MHz: Period = 8ns		|	 100MHz: Period = 40ns	 |	 10MHz: Period = 400ns 
set TX_CLK_125M_PERIOD	8
set TX_CLK_25M_PERIOD	40
set TX_CLK_2_5M_PERIOD	400


# Change the name of the RGMII core clocks on top level   
set	clk_in				"clk_clk"

# Change the other clock name on the top level
set	rgmii_rx_125M_virtualclk	"rgmii_rx_125M_virtualclk"
set	rgmii_rx_25M_virtualclk		"rgmii_rx_25M_virtualclk"
set	rgmii_rx_2_5M_virtualclk	"rgmii_rx_2_5M_virtualclk"

set	rgmii_rx_125M_clk	"rgmii_rx_125M_clk"
set	rgmii_rx_25M_clk	"rgmii_rx_25M_clk"
set	rgmii_rx_2_5M_clk	"rgmii_rx_2_5M_clk"

# Change the name of rgmii interface on the top level
set rgmii_tx_clk		"phy_rgmii_rgmii_tx_clk"
set	rgmii_out			"phy_rgmii_rgmii_txd"
set	rgmii_tx_control	"phy_rgmii_rgmii_tx_ctl"

set	rgmii_rx_clk		"phy_rgmii_rgmii_rx_clk"
set rgmii_in			"phy_rgmii_rgmii_rxd"
set	rgmii_rx_control	"phy_rgmii_rgmii_rx_ctl"


#**************************************************************
# Create Clock 
#**************************************************************

### FPGA clock 50MHz ###
create_clock -name FPGA_CLK_IN	-period "50 MHz" [get_ports clk_clk]

### PLL Clocks ###
# derive_pll_clocks -create_base_clocks
create_generated_clock -name PLL_OUT_CLK_2_5 -source [get_ports {clk_clk}] -divide_by 20 [get_pins {soc_0|pll_0|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}]
create_generated_clock -name PLL_OUT_CLK_25 -source [get_ports {clk_clk}] -divide_by 2 [get_pins {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk}]

### MDC clock 2.5MHz ###
create_clock -name MDC_SRC_CLK -period "2.5 MHz" [get_pins {soc_0|hps_0|fpga_interfaces|peripheral_emac0|gmii_mdc_o}]
create_generated_clock -name MDC_CLK_OUT -source [get_clocks {MDC_SRC_CLK}] [get_ports {emac0_fpga_mdc}]

### RGMII TX clock 125/25/2.5MHz ###
create_clock -name TX_SRC_CLK_125 -period "125 MHz" [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] -add
create_clock -name TX_SRC_CLK_25 -period "25 MHz" [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] -add
create_clock -name TX_SRC_CLK_2_5 -period "2.5 MHz" [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] -add
###### for creating max delay to path between hps and first flop in fpga
#create_generated_clock -name TX_SRC_CLK_125 -source [] [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] -add
#create_generated_clock -name TX_SRC_CLK_25 -source [get_pins {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk}] [get_keepers {soc_0|hps_0|fpga_interfaces|emac0_phy_txd_o}] -add
#create_generated_clock -name TX_SRC_CLK_2_5 -period "2.5 MHz" [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] -add

#create_generated_clock -name TX_CLK_OUT_125 \
#-source [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_125 [get_ports phy_rgmii_rgmii_tx_clk] -add
#create_generated_clock -name TX_CLK_OUT_25 \
#-source [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_25 [get_ports phy_rgmii_rgmii_tx_clk] -add
#create_generated_clock -name TX_CLK_OUT_2_5 \
#-source [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_2_5 [get_ports phy_rgmii_rgmii_tx_clk] -add

##### for creating tx clk from ddio
create_generated_clock -name TX_CLK_OUT_125 \
-source [get_pins {ddio_out_1|ALTDDIO_OUT_component|auto_generated|ddio_outa[0]|muxsel}] \
-master_clock TX_SRC_CLK_125 [get_ports phy_rgmii_rgmii_tx_clk] -add
create_generated_clock -name TX_CLK_OUT_25 \
-source [get_pins {ddio_out_1|ALTDDIO_OUT_component|auto_generated|ddio_outa[0]|muxsel}] \
-master_clock TX_SRC_CLK_25 [get_ports phy_rgmii_rgmii_tx_clk] -add
create_generated_clock -name TX_CLK_OUT_2_5 \
-source [get_pins {ddio_out_1|ALTDDIO_OUT_component|auto_generated|ddio_outa[0]|muxsel}] \
-master_clock TX_SRC_CLK_2_5 [get_ports phy_rgmii_rgmii_tx_clk] -add

#create_clock -name TX_SRC_CLK_125 -period "125 MHz" [get_keepers {cv_soc_rgmii_5csxfc6:soc_0|cv_soc_rgmii_5csxfc6_hps_0:hps_0|cv_soc_rgmii_5csxfc6_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] -add
#create_clock -name TX_SRC_CLK_25 -period "25 MHz" [get_keepers {cv_soc_rgmii_5csxfc6:soc_0|cv_soc_rgmii_5csxfc6_hps_0:hps_0|cv_soc_rgmii_5csxfc6_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] -add
#create_clock -name TX_SRC_CLK_2_5 -period "2.5 MHz" [get_keepers {cv_soc_rgmii_5csxfc6:soc_0|cv_soc_rgmii_5csxfc6_0:hps_0|cv_soc_rgmii_5csxfc6_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] -add

#create_generated_clock -name TX_CLK_OUT_125 \
#-source [get_keepers {cv_soc_rgmii_5csxfc6:soc_0|cv_soc_rgmii_5csxfc6_hps_0:hps_0|cv_soc_rgmii_5csxfc6_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_125 \
#[get_ports phy_rgmii_rgmii_tx_clk] \
#-add
#create_generated_clock -name TX_CLK_OUT_25 \
#-source [get_keepers {cv_soc_rgmii_5csxfc6:soc_0|cv_soc_rgmii_5csxfc6_hps_0:hps_0|cv_soc_rgmii_5csxfc6_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_25 \
#[get_ports phy_rgmii_rgmii_tx_clk] \
#-add
#create_generated_clock -name TX_CLK_OUT_2_5 \
#-source [get_keepers {cv_soc_rgmii_5csxfc6:soc_0|cv_soc_rgmii_5csxfc6_hps_0:hps_0|cv_soc_rgmii_5csxfc6_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_2_5 \
#[get_ports phy_rgmii_rgmii_tx_clk] \
#-add



### RGMII RX clock 125/25/2.5MHz, create clock with 90 degree shift for center align ###
create_clock -name RX_CLK_IN_125 -period 8   -waveform {2 6}     [get_ports phy_rgmii_rgmii_rx_clk]
create_clock -name RX_CLK_IN_25  -period 40  -waveform {10 30}   [get_ports phy_rgmii_rgmii_rx_clk] -add
create_clock -name RX_CLK_IN_2_5 -period 400 -waveform {100 300} [get_ports phy_rgmii_rgmii_rx_clk] -add



#**************************************************************
# Virtual Clock
#************************************************************** 
# Virtual Clock is the clock outside the FPGA.  It is also used 
# to differentiate the clock uncertainty between
# Input to Register, Register to Register and Output to Register

create_clock -name RX_VIRT_CLK_125 	-period "125 MHz" 
create_clock -name RX_VIRT_CLK_25 	-period "25 MHz" 	
create_clock -name RX_VIRT_CLK_2_5 	-period "2.5 MHz" 



#**************************************************************
# Delays
#************************************************************** 
# Input delay and output delay to each IO pins
### TX path output delay ###
set_output_delay -clock TX_CLK_OUT_125 -min -2.95 \
[get_ports "phy_rgmii_rgmii_txd* phy_rgmii_rgmii_tx_ctl"] -add_delay
set_output_delay -clock TX_CLK_OUT_125 -max -0.85 \
[get_ports "phy_rgmii_rgmii_txd* phy_rgmii_rgmii_tx_ctl"] -add_delay
set_output_delay -clock TX_CLK_OUT_125 -min -2.95 \
[get_ports "phy_rgmii_rgmii_txd* phy_rgmii_rgmii_tx_ctl"] -clock_fall -add_delay
set_output_delay -clock TX_CLK_OUT_125 -max -0.85 \
[get_ports "phy_rgmii_rgmii_txd* phy_rgmii_rgmii_tx_ctl"] -clock_fall -add_delay

### RX path input delays ###
#Latest change 30042014
# --------------------------------------------------------
# Take tco of External Phy and path delay difference between 
# data and clock into timing analysis consideration for 125M clock
# The formula to calculate the input delay is provided in AN433
 
 #Set Input Delay for 1G ,100m and 10M:
 #-max [expr  ($RX_CLK_125M_PERIOD/4) - $max_rx_setup ]= 1
 #-min [expr  -($RX_CLK_125M_PERIOD/4)-$min_rx_hold]  = -1
set_input_delay -clock  [get_clocks RX_VIRT_CLK_125] -max 0.8 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_125] -max 0.8 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -clock_fall -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_125] -min -1 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_125] -min -1 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -clock_fall -add_delay

 #--------------------------------------------------------
 #Take tco of External Phy and path delay difference between 
 #data and clock into timing analysis consideration for 25M clock
set_input_delay -clock  [get_clocks RX_VIRT_CLK_25] -max 0.8 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_25] -max 0.8 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -clock_fall -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_25] -min -1 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_25] -min -1\
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -clock_fall -add_delay   

 #--------------------------------------------------------
 #Take tco of External Phy and path delay difference between 
 #data and clock into timing analysis consideration for 2.5M clock
set_input_delay -clock  [get_clocks RX_VIRT_CLK_2_5] -max 0.8 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_2_5] -max 0.8 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -clock_fall -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_2_5] -min -1 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -add_delay
set_input_delay -clock  [get_clocks RX_VIRT_CLK_2_5] -min -1 \
[get_ports "phy_rgmii_rgmii_rxd* phy_rgmii_rgmii_rx_ctl"] -clock_fall -add_delay




#**************************************************************
# Multi-cycles & False paths
#************************************************************** 
### to align the launch edge with the latch edge ###
set_multicycle_path 0 -setup -end -rise_from [get_clocks "TX_SRC_CLK_125 TX_SRC_CLK_25 TX_SRC_CLK_2_5"] -rise_to  [get_clocks "TX_CLK_OUT_125 TX_CLK_OUT_25 TX_CLK_OUT_2_5"]
set_multicycle_path 0 -setup -end -fall_from [get_clocks "TX_SRC_CLK_125 TX_SRC_CLK_25 TX_SRC_CLK_2_5"] -fall_to  [get_clocks "TX_CLK_OUT_125 TX_CLK_OUT_25 TX_CLK_OUT_2_5"]

### false path for different edge between lauch and latch clocks ###
set_false_path -fall_from [get_clocks "TX_SRC_CLK_125 TX_SRC_CLK_25 TX_SRC_CLK_2_5"] \
-rise_to [get_clocks "TX_CLK_OUT_125 TX_CLK_OUT_25 TX_CLK_OUT_2_5"] -setup
set_false_path -rise_from [get_clocks "TX_SRC_CLK_125 TX_SRC_CLK_25 TX_SRC_CLK_2_5"] \
-fall_to [get_clocks "TX_CLK_OUT_125 TX_CLK_OUT_25 TX_CLK_OUT_2_5"] -setup
set_false_path -fall_from [get_clocks "TX_SRC_CLK_125 TX_SRC_CLK_25 TX_SRC_CLK_2_5"] \
-fall_to [get_clocks "TX_CLK_OUT_125 TX_CLK_OUT_25 TX_CLK_OUT_2_5"] -hold
set_false_path -rise_from [get_clocks "TX_SRC_CLK_125 TX_SRC_CLK_25 TX_SRC_CLK_2_5"] \
-rise_to [get_clocks "TX_CLK_OUT_125 TX_CLK_OUT_25 TX_CLK_OUT_2_5"] -hold

### false path between virtual clk and rx clock ###
# Determine the desired setup and hold relationship in order to
# let TimeQuest analyze only the correct pair of launch-latch setup and hold relationship
set_false_path -fall_from [get_clocks "RX_VIRT_CLK_125 RX_VIRT_CLK_25 RX_VIRT_CLK_2_5"] \
-rise_to [get_clocks "RX_CLK_IN_125 RX_CLK_IN_25 RX_CLK_IN_2_5"] -setup
set_false_path -rise_from [get_clocks "RX_VIRT_CLK_125 RX_VIRT_CLK_25 RX_VIRT_CLK_2_5"] \
-fall_to [get_clocks "RX_CLK_IN_125 RX_CLK_IN_25 RX_CLK_IN_2_5"] -setup
set_false_path -fall_from [get_clocks "RX_VIRT_CLK_125 RX_VIRT_CLK_25 RX_VIRT_CLK_2_5"] \
-fall_to [get_clocks "RX_CLK_IN_125 RX_CLK_IN_25 RX_CLK_IN_2_5"] -hold
set_false_path -rise_from [get_clocks "RX_VIRT_CLK_125 RX_VIRT_CLK_25 RX_VIRT_CLK_2_5"] \
-rise_to [get_clocks "RX_CLK_IN_125 RX_CLK_IN_25 RX_CLK_IN_2_5"] -hold



#**************************************************************
# Derive Clock Uncertainty
#**************************************************************

derive_clock_uncertainty -add


#**************************************************************
# Create Generated Clock
#**************************************************************

#create_clock -name TX_SRC_CLK_125 -period 8.000 [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] -add

#create_clock -name TX_SRC_CLK_25 -period 40.000 [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] -add

#create_clock -name TX_SRC_CLK_2_5 -period 400.000 [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] -add

#create_clock -name TX_SRC_CLK_125 -period 8.000 [get_keepers {soc_system:soc_0|soc_system_hps_0:hps_0|soc_system_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] -add

#create_clock -name TX_SRC_CLK_25 -period 40.000 [get_keepers {soc_system:soc_0|soc_system_hps_0:hps_0|soc_system_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] -add

#create_clock -name TX_SRC_CLK_2_5 -period 400.000 [get_keepers {soc_system:soc_0|soc_system_hps_0:hps_0|soc_system_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] -add



#create_generated_clock -name clk_25M_pll -source [get_ports {clk_in}] -divide_by 2 [get_pins {soc_0|pll_0|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}]

#create_generated_clock -name clk_2_5M_pll -source [get_ports {clk_in}] -divide_by 20 [get_pins {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk}]



#**************************************************************
# RGMII TX CLOCK
#**************************************************************
# It doesn't use virtual clock as to include the delay generated by
# in the timing analysis
# -phase 90:Tells timing analysis that there is a phase-shift externaly.
# It have no effect inside the FPGA

#create_generated_clock -name TX_CLK_OUT_125 \
#-source [get_keepers {soc_system:soc_0|soc_system_hps_0:hps_0|soc_system_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}]\
#-master_clock TX_SRC_CLK_125 \
#[get_ports $rgmii_tx_clk] \
#-add

#create_generated_clock -name TX_CLK_OUT_25 \
#-source [get_keepers {soc_system:soc_0|soc_system_hps_0:hps_0|soc_system_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_25 \
#[get_ports $rgmii_tx_clk] \
#-add

#create_generated_clock -name TX_CLK_OUT_2_5 \
#-source [get_keepers {soc_system:soc_0|soc_system_hps_0:hps_0|soc_system_hps_0_fpga_interfaces:fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_2_5 \
#[get_ports $rgmii_tx_clk] \
#-add

#create_generated_clock -name TX_CLK_OUT_125 \
#-source [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}]\
#-master_clock TX_SRC_CLK_125 \
#[get_ports $rgmii_tx_clk] \
#-add

#create_generated_clock -name TX_CLK_OUT_25 \
#-source [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_25 \
#[get_ports $rgmii_tx_clk] \
#-add

#create_generated_clock -name TX_CLK_OUT_2_5 \
#-source [get_keepers {soc_0|hps_0|fpga_interfaces|peripheral_emac0~internal_clock}] \
#-master_clock TX_SRC_CLK_2_5 \
#[get_ports $rgmii_tx_clk] \
#-add

#**************************************************************
# Set Clock Groups / Set False Path
#**************************************************************

set_clock_groups -exclusive \
-group "TX_SRC_CLK_125 TX_CLK_OUT_125 RX_CLK_IN_125 RX_VIRT_CLK_125"  \
-group "TX_SRC_CLK_25	PLL_OUT_CLK_25 TX_CLK_OUT_25 RX_CLK_IN_25 RX_VIRT_CLK_25"  \
-group "TX_SRC_CLK_2_5 PLL_OUT_CLK_2_5 TX_CLK_OUT_2_5 RX_CLK_IN_2_5 RX_VIRT_CLK_2_5" 

set_clock_groups -asynchronous \
-group {TX_SRC_CLK_125 TX_SRC_CLK_25 TX_SRC_CLK_2_5 TX_CLK_OUT_125 TX_CLK_OUT_25 TX_CLK_OUT_2_5 } \
-group {FPGA_CLK_IN} \
-group "RX_CLK_IN_125 RX_CLK_IN_25 RX_CLK_IN_2_5"\
-group "PLL_OUT_CLK_25 PLL_OUT_CLK_2_5"


#**************************************************************
# Transmit Side (External PHY Delay is Turn On)
#**************************************************************
# Same Edge Capture Center Align: launch at positive edge and latch at positive edge
# Determine the desired setup and hold relationship in order to
# let TimeQuest analyze only the correct pair of launch-latch setup and hold relationship


set_false_path -from {soc_0|pll_0|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk} -to {TX_SRC_CLK_125}
set_false_path -from {TX_SRC_CLK_125} -to {soc_0|pll_0|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}

set_false_path -from {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk} -to {TX_SRC_CLK_125}
set_false_path -from {TX_SRC_CLK_125} -to {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk}


# The formula to calculate the output delay is provided in AN433
#if { $::quartus(nameofexecutable) == "quartus_fit" } {

#set_max_delay -from [get_pins {soc_0|hps_0|fpga_interfaces|peripheral_emac0|phy_txclk_o}] -to [get_ports {phy_rgmii_rgmii_tx*}] -2

#set_max_skew -from_clock { rgmii_rx_125M_virtualclk } -to_clock { rgmii_rx_125M_clk } -from phy_rgmii_rgmii_rx* -to * 3

#set_max_skew -from_clock { rgmii_rx_125M_virtualclk } -to_clock { rgmii_rx_125M_clk } -from [get_ports {phy_rgmii_rgmii_rx_ctl phy_rgmii_rgmii_rxd[0] phy_rgmii_rgmii_rxd[1] phy_rgmii_rgmii_rxd[2] phy_rgmii_rgmii_rxd[3]}] -to [get_ports {*}] -include { input_delay } 3

#}

set_output_delay -max 2 -clock [get_clocks {MDC_CLK_OUT}] [get_ports {emac0_fpga_mdio}]
set_output_delay -min 1 -clock [get_clocks {MDC_CLK_OUT}] [get_ports {emac0_fpga_mdio}]

#lekong

#
#set_output_delay -clock TX_CLK_OUT_25 \
#-min -5.0 \
#[get_ports "$rgmii_out* $rgmii_tx_control"] \
#-add_delay

#set_output_delay -clock TX_CLK_OUT_25 \
#-min -5.0 \
#[get_ports "$rgmii_out* $rgmii_tx_control"] \
#-clock_fall \
#-add_delay

#set_output_delay -clock TX_CLK_OUT_25 \
#-max -2.50 \
#[get_ports "$rgmii_out* $rgmii_tx_control"] \
#-add_delay 

#set_output_delay -clock TX_CLK_OUT_25 \
#-max -2.50  \
#[get_ports "$rgmii_out* $rgmii_tx_control"] \
#-clock_fall \
#-add_delay



#set_output_delay -clock TX_CLK_OUT_2_5 \
#-min -6.5 \
#[get_ports "$rgmii_out* $rgmii_tx_control"] \
#-add_delay

#set_output_delay -clock TX_CLK_OUT_2_5 \
#-min -6.5  \
#[get_ports "$rgmii_out* $rgmii_tx_control"] \
#-clock_fall \
#-add_delay

#set_output_delay -clock TX_CLK_OUT_2_5 \
#-max -3.5  \
#[get_ports "$rgmii_out* $rgmii_tx_control"] \
#-add_delay

#set_output_delay -clock TX_CLK_OUT_2_5 \
#-max -3.5  \
#[get_ports "$rgmii_out* $rgmii_tx_control"] \
#-clock_fall  \
#-add_delay


#**************************************************************
# Receiver Side (External PHY Delay is Turn On)
#**************************************************************
# Same Edge Capture Center Align: launch at positive edge and latch at positive edge



#set false path between data input clock and data output clock

set_false_path -from [get_clocks {RX_VIRT_CLK_125 rgmii_rx_2_5M_clk RX_VIRT_CLK_2_5 rgmii_rx_25M_clk RX_VIRT_CLK_25 rgmii_rx_125M_clk}] -to [get_clocks {TX_CLK_OUT_2_5 TX_CLK_OUT_25 TX_CLK_OUT_125 TX_SRC_CLK_2_5 TX_SRC_CLK_25 TX_SRC_CLK_125}]
set_false_path -from [get_clocks {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk}] -to [get_clocks {rgmii_rx_125M_clk}]
set_false_path -from [get_clocks {soc_0|pll_0|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}] -to [get_clocks {rgmii_rx_125M_clk}]
set_false_path -from [get_clocks {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk}] -to [get_clocks {rgmii_rx_25M_clk}]
set_false_path -from [get_clocks {soc_0|pll_0|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}] -to [get_clocks {rgmii_rx_25M_clk}]
set_false_path -from [get_clocks {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk}] -to [get_clocks {rgmii_rx_2_5M_clk}]
set_false_path -from [get_clocks {soc_0|pll_0|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}] -to [get_clocks {rgmii_rx_2_5M_clk}]

set_false_path -from [get_clocks {rgmii_rx_125M_clk}] -to [get_clocks {soc_0|pll_0|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}]
set_false_path -from [get_clocks {rgmii_rx_125M_clk}] -to [get_clocks {soc_0|pll_0|altera_pll_i|general[1].gpll~PLL_OUTPUT_COUNTER|divclk}]

# for enhancing USB BlasterII to be reliable, 16MHz
create_clock -name {altera_reserved_tck} -period "16 MHz" {altera_reserved_tck}
set_input_delay -clock altera_reserved_tck -clock_fall 3 [get_ports altera_reserved_tdi]
set_input_delay -clock altera_reserved_tck -clock_fall 3 [get_ports altera_reserved_tms]
set_output_delay -clock altera_reserved_tck 3 [get_ports altera_reserved_tdo]

# FPGA IO port constraints
set_false_path -from [get_ports {fpga_button_pio[0]}] -to *
set_false_path -from [get_ports {fpga_button_pio[1]}] -to *
set_false_path -from [get_ports {fpga_dipsw_pio[0]}] -to *
set_false_path -from [get_ports {fpga_dipsw_pio[1]}] -to *
set_false_path -from [get_ports {fpga_dipsw_pio[2]}] -to *
set_false_path -from [get_ports {fpga_dipsw_pio[3]}] -to *
set_false_path -from * -to [get_ports {fpga_led_pio[0]}]
set_false_path -from * -to [get_ports {fpga_led_pio[1]}]
set_false_path -from * -to [get_ports {fpga_led_pio[2]}]
set_false_path -from * -to [get_ports {fpga_led_pio[3]}]

# HPS peripherals port false path setting to workaround the unconstraint path (setting false_path for hps_0 ports will not affect the routing as it is hard silicon)
set_false_path -from * -to [get_ports {hps_*emac1_*TX_CLK}] 
set_false_path -from * -to [get_ports {hps_*emac1_*TXD0}] 
set_false_path -from * -to [get_ports {hps_*emac1_*TXD1}] 
set_false_path -from * -to [get_ports {hps_*emac1_*TXD2}] 
set_false_path -from * -to [get_ports {hps_*emac1_*TXD3}] 
set_false_path -from * -to [get_ports {hps_*emac1_*MDC}] 
set_false_path -from * -to [get_ports {hps_*emac1_*TX_CTL}] 
set_false_path -from * -to [get_ports {hps_*qspi_*SS0}] 
set_false_path -from * -to [get_ports {hps_*qspi_*CLK}] 
set_false_path -from * -to [get_ports {hps_*sdio_*CLK}] 
set_false_path -from * -to [get_ports {hps_*usb1_*STP}] 
set_false_path -from * -to [get_ports {hps_*spim0_*CLK}] 
set_false_path -from * -to [get_ports {hps_*spim0_*MOSI}] 
set_false_path -from * -to [get_ports {hps_*spim0_*SS0}] 
set_false_path -from * -to [get_ports {hps_*uart0_*TX}] 
set_false_path -from * -to [get_ports {hps_*can0_*TX}] 
set_false_path -from * -to [get_ports {hps_*trace_*CLK}] 
set_false_path -from * -to [get_ports {hps_*trace_*D0}] 
set_false_path -from * -to [get_ports {hps_*trace_*D1}] 
set_false_path -from * -to [get_ports {hps_*trace_*D2}] 
set_false_path -from * -to [get_ports {hps_*trace_*D3}] 
set_false_path -from * -to [get_ports {hps_*trace_*D4}] 
set_false_path -from * -to [get_ports {hps_*trace_*D5}] 
set_false_path -from * -to [get_ports {hps_*trace_*D6}] 
set_false_path -from * -to [get_ports {hps_*trace_*D7}] 

set_false_path -from * -to [get_ports {hps_*emac1_*MDIO}] 
set_false_path -from * -to [get_ports {hps_*qspi_*IO0}] 
set_false_path -from * -to [get_ports {hps_*qspi_*IO1}] 
set_false_path -from * -to [get_ports {hps_*qspi_*IO2}] 
set_false_path -from * -to [get_ports {hps_*qspi_*IO3}] 
set_false_path -from * -to [get_ports {hps_*sdio_*CMD}] 
set_false_path -from * -to [get_ports {hps_*sdio_*D0}] 
set_false_path -from * -to [get_ports {hps_*sdio_*D1}] 
set_false_path -from * -to [get_ports {hps_*sdio_*D2}] 
set_false_path -from * -to [get_ports {hps_*sdio_*D3}] 
set_false_path -from * -to [get_ports {hps_*usb1_*D0}] 
set_false_path -from * -to [get_ports {hps_*usb1_*D1}] 
set_false_path -from * -to [get_ports {hps_*usb1_*D2}] 
set_false_path -from * -to [get_ports {hps_*usb1_*D3}] 
set_false_path -from * -to [get_ports {hps_*usb1_*D4}] 
set_false_path -from * -to [get_ports {hps_*usb1_*D5}] 
set_false_path -from * -to [get_ports {hps_*usb1_*D6}] 
set_false_path -from * -to [get_ports {hps_*usb1_*D7}] 
set_false_path -from * -to [get_ports {hps_*i2c0_*SDA}] 
set_false_path -from * -to [get_ports {hps_*i2c0_*SCL}] 
set_false_path -from * -to [get_ports {hps_*gpio_*GPIO09}] 
set_false_path -from * -to [get_ports {hps_*gpio_*GPIO35}] 
set_false_path -from * -to [get_ports {hps_*gpio_*GPIO41}] 
set_false_path -from * -to [get_ports {hps_*gpio_*GPIO42}] 
set_false_path -from * -to [get_ports {hps_*gpio_*GPIO43}] 
set_false_path -from * -to [get_ports {hps_*gpio_*GPIO44}] 

set_false_path -from [get_ports {hps_*emac1_*MDIO}] -to *
set_false_path -from [get_ports {hps_*qspi_*IO0}] -to *
set_false_path -from [get_ports {hps_*qspi_*IO1}] -to *
set_false_path -from [get_ports {hps_*qspi_*IO2}] -to *
set_false_path -from [get_ports {hps_*qspi_*IO3}] -to *
set_false_path -from [get_ports {hps_*sdio_*CMD}] -to *
set_false_path -from [get_ports {hps_*sdio_*D0}] -to *
set_false_path -from [get_ports {hps_*sdio_*D1}] -to *
set_false_path -from [get_ports {hps_*sdio_*D2}] -to *
set_false_path -from [get_ports {hps_*sdio_*D3}] -to *
set_false_path -from [get_ports {hps_*usb1_*D0}] -to *
set_false_path -from [get_ports {hps_*usb1_*D1}] -to *
set_false_path -from [get_ports {hps_*usb1_*D2}] -to *
set_false_path -from [get_ports {hps_*usb1_*D3}] -to *
set_false_path -from [get_ports {hps_*usb1_*D4}] -to *
set_false_path -from [get_ports {hps_*usb1_*D5}] -to *
set_false_path -from [get_ports {hps_*usb1_*D6}] -to *
set_false_path -from [get_ports {hps_*usb1_*D7}] -to *
set_false_path -from [get_ports {hps_*i2c0_*SDA}] -to *
set_false_path -from [get_ports {hps_*i2c0_*SCL}] -to *
set_false_path -from [get_ports {hps_*gpio_*GPIO09}] -to *
set_false_path -from [get_ports {hps_*gpio_*GPIO35}] -to *
set_false_path -from [get_ports {hps_*gpio_*GPIO41}] -to *
set_false_path -from [get_ports {hps_*gpio_*GPIO42}] -to *
set_false_path -from [get_ports {hps_*gpio_*GPIO43}] -to *
set_false_path -from [get_ports {hps_*gpio_*GPIO44}] -to *

set_false_path -from [get_ports {hps_*emac1_*RX_CTL}] -to *
set_false_path -from [get_ports {hps_*emac1_*RX_CLK}] -to *
set_false_path -from [get_ports {hps_*emac1_*RXD0}] -to *
set_false_path -from [get_ports {hps_*emac1_*RXD1}] -to *
set_false_path -from [get_ports {hps_*emac1_*RXD2}] -to *
set_false_path -from [get_ports {hps_*emac1_*RXD3}] -to *
set_false_path -from [get_ports {hps_*usb1_*CLK}] -to *
set_false_path -from [get_ports {hps_*usb1_*DIR}] -to *
set_false_path -from [get_ports {hps_*usb1_*NXT}] -to *
set_false_path -from [get_ports {hps_*spim0_*MISO}] -to *
set_false_path -from [get_ports {hps_*uart0_*RX}] -to *
set_false_path -from [get_ports {hps_*can0_*RX}] -to *

# create unused clock constraint for HPS I2C and usb1 to avoid misleading unconstraint clock reporting in TimeQuest
create_clock -period "1 MHz" [get_ports hps*_i2c0_*SCL]
create_clock -period "48 MHz" [get_ports hps*_usb1_*CLK]

# Set Max Delay

#set_max_delay -from [get_pins {soc_0|hps_0|fpga_interfaces|peripheral_emac0|phy_txclk_o}] -to [get_ports *rgmii_txd*] 4


# Remove old SDC from fpga_interfaces.sdc
#remove_clock [get_pins -compatibility_mode {*|fpga_interfaces|peripheral_emac0|phy_txclk_o}]
